@@ -120,8 +120,8 @@ pub fn visit_file_defs(
 ///
 /// Note that, by default, rust-analyzer tests **do not** include core or std
 /// libraries. If you are writing tests for functionality using [`FamousDefs`],
-/// you'd want to include [minicore](test_utils::MiniCore) declaration at the
-/// start of your tests:
+/// you'd want to include minicore (see `test_utils::MiniCore`) declaration at
+/// the start of your tests:
 ///
 /// ```
 /// //- minicore: iterator, ord, derive
@@ -271,7 +271,20 @@ pub fn for_each_tail_expr(expr: &ast::Expr, cb: &mut dyn FnMut(&ast::Expr)) {
             ast::Effect::Async(_) | ast::Effect::Try(_) | ast::Effect::Const(_) => cb(expr),
         },
         ast::Expr::IfExpr(if_) => {
-            if_.blocks().for_each(|block| for_each_tail_expr(&ast::Expr::BlockExpr(block), cb))
+            let mut if_ = if_.clone();
+            loop {
+                if let Some(block) = if_.then_branch() {
+                    for_each_tail_expr(&ast::Expr::BlockExpr(block), cb);
+                }
+                match if_.else_branch() {
+                    Some(ast::ElseBranch::IfExpr(it)) => if_ = it,
+                    Some(ast::ElseBranch::Block(block)) => {
+                        for_each_tail_expr(&ast::Expr::BlockExpr(block), cb);
+                        break;
+                    }
+                    None => break,
+                }
+            }
         }
         ast::Expr::LoopExpr(l) => {
             for_each_break_expr(l.label(), l.loop_body(), &mut |b| cb(&ast::Expr::BreakExpr(b)))
